@@ -6,8 +6,10 @@ module HLint(hlint) where
 import Control.Applicative
 import Control.Monad.Extra
 import Control.Exception
+import Control.Concurrent.Extra
 import System.Console.CmdArgs.Verbosity
 import Data.List
+import GHC.Conc
 import System.Exit
 import System.IO.Extra
 import Data.Tuple.Extra
@@ -20,7 +22,8 @@ import System.Directory
 import Text.ParserCombinators.ReadP
 
 import CmdLine
-import Settings
+import Config.Type
+import Config.Haskell
 import Report
 import Idea
 import Apply
@@ -111,8 +114,8 @@ runHlintMain :: Cmd -> Maybe FilePath -> ParseFlags -> IO [Idea]
 runHlintMain cmd@CmdMain{..} fp flags = do
   files <- concatMapM (resolveFile cmd fp) cmdFiles
   if null files
-    then error "No files found"
-    else runHints cmd{cmdFiles=files} flags
+      then error "No files found"
+      else runHints cmd{cmdFiles=files} flags
 
 {-# ANN readAllSettings "HLint: ignore Use let" #-}
 readAllSettings :: Cmd -> ParseFlags -> IO [Setting]
@@ -126,71 +129,88 @@ readAllSettings cmd@CmdMain{..} flags = do
 
 runHints :: Cmd -> ParseFlags -> IO [Idea]
 runHints cmd@CmdMain{..} flags = do
-    let outStrLn = whenNormal . putStrLn
-    settings <- readAllSettings cmd flags
+    j <- if cmdThreads == 0 then getNumProcessors else return cmdThreads
+    withNumCapabilities j $ do
+        let outStrLn = whenNormal . putStrLn
+        settings <- readAllSettings cmd flags
+        ideas <- getIdeas cmd settings flags
+        let (showideas,hideideas) = partition (\i -> cmdShowAll || ideaSeverity i /= Ignore) ideas
+        if cmdJson then
+            putStrLn $ showIdeasJson showideas
+         else if cmdSerialise then do
+            hSetBuffering stdout NoBuffering
+            print $ map (show &&& ideaRefactoring) showideas
+         else if cmdRefactor then
+            handleRefactoring showideas cmdFiles cmd
+         else do
+            usecolour <- cmdUseColour cmd
+            showItem <- if usecolour then showANSI else return show
+            mapM_ (outStrLn . showItem) showideas
+            handleReporting showideas hideideas cmd
+        return showideas
 
+getIdeas :: Cmd -> [Setting] -> ParseFlags -> IO [Idea]
+getIdeas cmd@CmdMain{..} settings flags = do
     ideas <- if cmdCross
         then applyHintFiles flags settings cmdFiles
-        else concat <$> parallel [evaluateList =<< applyHintFile flags settings x Nothing | x <- cmdFiles]
-    let (showideas,hideideas) = partition (\i -> cmdShowAll || ideaSeverity i /= Ignore) ideas
-    usecolour <- cmdUseColour cmd
-    showItem <- if usecolour then showANSI else return show
-    if cmdJson
-        then putStrLn . showIdeasJson $ showideas
-        else if cmdSerialise then do
-          hSetBuffering stdout NoBuffering
-          print $ map (show &&& ideaRefactoring) showideas
-        else if cmdRefactor then
-          case cmdFiles of
-            [file] -> do
-              -- Ensure that we can find the executable
-              path <- checkRefactor (if cmdWithRefactor == "" then Nothing else Just cmdWithRefactor)
-              -- writeFile "hlint.refact"
-              let hints =  show $ map (show &&& ideaRefactoring) showideas
-              withTempFile $ \f -> do
-                writeFile f hints
-                runRefactoring path file f cmdRefactorOptions
-                -- Exit with the exit code from 'refactor'
-                >>= exitWith
-            _ -> error "Refactor flag can only be used with an individual file"
+        else concat <$> parallel cmdThreads [evaluateList =<< applyHintFile flags settings x Nothing | x <- cmdFiles]
+    return $ if not (null cmdOnly)
+        then [i | i <- ideas, ideaHint i `elem` cmdOnly]
+        else ideas
 
-        else do
-            mapM_ (outStrLn . showItem) showideas
-            if null showideas then
-                when (cmdReports /= []) $ outStrLn "Skipping writing reports"
-             else
-                forM_ cmdReports $ \x -> do
-                    outStrLn $ "Writing report to " ++ x ++ " ..."
-                    writeReport cmdDataDir x showideas
-            unless cmdNoSummary $
-                outStrLn $
-                    (let i = length showideas in if i == 0 then "No hints" else show i ++ " hint" ++ ['s' | i/=1]) ++
-                    (let i = length hideideas in if i == 0 then "" else " (" ++ show i ++ " ignored)")
-    return showideas
+handleRefactoring :: [Idea] -> [String] -> Cmd -> IO ()
+handleRefactoring showideas files cmd@CmdMain{..} =
+    case cmdFiles of
+        [file] -> do
+            -- Ensure that we can find the executable
+            path <- checkRefactor (if cmdWithRefactor == "" then Nothing else Just cmdWithRefactor)
+            -- writeFile "hlint.refact"
+            let hints =  show $ map (show &&& ideaRefactoring) showideas
+            withTempFile $ \f -> do
+                writeFile f hints
+                exitWith =<< runRefactoring path file f cmdRefactorOptions
+        _ -> error "Refactor flag can only be used with an individual file"
+
+
+handleReporting :: [Idea] -> [Idea] -> Cmd -> IO ()
+handleReporting showideas hideideas cmd@CmdMain{..} = do
+    let outStrLn = whenNormal . putStrLn
+    if null showideas then
+        when (cmdReports /= []) $ outStrLn "Skipping writing reports"
+     else
+        forM_ cmdReports $ \x -> do
+            outStrLn $ "Writing report to " ++ x ++ " ..."
+            writeReport cmdDataDir x showideas
+    unless cmdNoSummary $
+        outStrLn $
+            (let i = length showideas in if i == 0 then "No hints" else show i ++ " hint" ++ ['s' | i/=1]) ++
+            (let i = length hideideas in if i == 0 then "" else " (" ++ show i ++ " ignored)")
 
 runRefactoring :: FilePath -> FilePath -> FilePath -> String -> IO ExitCode
 runRefactoring rpath fin hints opts =  do
-  let args = [fin, "-v0"] ++ words opts ++ ["--refact-file", hints]
-  (_, _, _, phand) <- createProcess $ proc rpath args
-  try $ hSetBuffering stdin LineBuffering :: IO (Either IOException ())
-  hSetBuffering stdout LineBuffering
-  -- Propagate the exit code from the spawn process
-  waitForProcess phand
+    let args = [fin, "-v0"] ++ words opts ++ ["--refact-file", hints]
+    (_, _, _, phand) <- createProcess $ proc rpath args
+    try $ hSetBuffering stdin LineBuffering :: IO (Either IOException ())
+    hSetBuffering stdout LineBuffering
+    -- Propagate the exit code from the spawn process
+    waitForProcess phand
 
 checkRefactor :: Maybe FilePath -> IO FilePath
 checkRefactor rpath = do
-  let excPath = fromMaybe "refactor" rpath
-  mexc <- findExecutable excPath
-  case mexc of
-    Just exc ->  do
-      vers <- readP_to_S parseVersion . tail <$> readProcess exc ["--version"] ""
-      case vers of
-        [] -> putStrLn "Unabled to determine version of refactor" >> return exc
-        (last -> (version, _)) -> if versionBranch version >= [0,1,0,0]
-                                    then return exc
-                                    else error "Your version of refactor is too old, please upgrade to the latest version"
-    Nothing ->  error $ unlines [ "Could not find refactor"
-                                , "Tried with: " ++ excPath ]
+    let excPath = fromMaybe "refactor" rpath
+    mexc <- findExecutable excPath
+    case mexc of
+        Just exc ->  do
+            vers <- readP_to_S parseVersion . tail <$> readProcess exc ["--version"] ""
+            case vers of
+                [] -> putStrLn "Unabled to determine version of refactor" >> return exc
+                (last -> (version, _)) ->
+                    if versionBranch version >= [0,1,0,0]
+                        then return exc
+                        else error "Your version of refactor is too old, please upgrade to the latest version"
+        Nothing -> error $ unlines [ "Could not find refactor", "Tried with: " ++ excPath ]
 
 evaluateList :: [a] -> IO [a]
-evaluateList xs = length xs `seq` return xs
+evaluateList xs = do
+    evaluate $ length xs
+    return xs
