@@ -8,7 +8,7 @@ module HSE.All(
     ) where
 
 import HSE.Util as X
-import HSE.Evaluate as X
+import HSE.Reduce as X
 import HSE.Type as X
 import HSE.Bracket as X
 import HSE.Match as X
@@ -42,6 +42,7 @@ parseFlagsNoLocations :: ParseFlags -> ParseFlags
 parseFlagsNoLocations x = x{cppFlags = case cppFlags x of Cpphs y -> Cpphs $ f y; y -> y}
     where f x = x{boolopts = (boolopts x){locations=False}}
 
+-- | Given some fixities, add them to the existing fixities in 'ParseFlags'.
 parseFlagsAddFixities :: [Fixity] -> ParseFlags -> ParseFlags
 parseFlagsAddFixities fx x = x{hseFlags=hse{fixities = Just $ fx ++ fromMaybe [] (fixities hse)}}
     where hse = hseFlags x
@@ -72,7 +73,7 @@ data ParseError = ParseError
 
 -- | Parse a Haskell module. Applies the C pre processor, and uses best-guess fixity resolution if there are ambiguities.
 --   The filename @-@ is treated as @stdin@. Requires some flags (often 'defaultParseFlags'), the filename, and optionally the contents of that file.
-parseModuleEx :: ParseFlags -> FilePath -> Maybe String -> IO (Either ParseError (Module SrcSpanInfo, [Comment]))
+parseModuleEx :: ParseFlags -> FilePath -> Maybe String -> IO (Either ParseError (Module_, [Comment]))
 parseModuleEx flags file str = do
         str <- maybe (readFileEncoding' (encoding flags) file) return str
         str <- return $ fromMaybe str $ stripPrefix "\65279" str -- remove the BOM if it exists, see #130
@@ -127,8 +128,8 @@ cheapFixities fixs = descendBi (transform f)
         ask = askFixity fixs
 
         f o@(InfixApp s1 (InfixApp s2 x op1 y) op2 z)
-                | p1 == p2 && (a1 /= a2 || a1 == AssocNone) = o -- Ambiguous infix expression!
-                | p1 > p2 || p1 == p2 && (a1 == AssocLeft || a2 == AssocNone) = o
+                | p1 == p2 && (a1 /= a2 || isAssocNone a1) = o -- Ambiguous infix expression!
+                | p1 > p2 || p1 == p2 && (isAssocLeft a1 || isAssocNone a2) = o
                 | otherwise = InfixApp s1 x op1 (f $ InfixApp s1 y op2 z)
             where
                 (a1,p1) = ask op1
@@ -136,7 +137,7 @@ cheapFixities fixs = descendBi (transform f)
         f x = x
 
 
-askFixity :: [Fixity] -> QOp S -> (Assoc, Int)
-askFixity xs = \k -> Map.findWithDefault (AssocLeft, 9) (fromNamed k) mp
+askFixity :: [Fixity] -> QOp S -> (Assoc (), Int)
+askFixity xs = \k -> Map.findWithDefault (AssocLeft (), 9) (fromNamed k) mp
     where
-        mp = Map.fromList [(s,(a,p)) | Fixity a p x <- xs, let s = fromNamed x, s /= ""]
+        mp = Map.fromList [(s,(a,p)) | Fixity a p x <- xs, let s = fromNamed $ fmap (const an) x, s /= ""]
