@@ -9,7 +9,6 @@ module HSE.Match(
 import Data.Char
 import HSE.Type
 import HSE.Util
-import qualified Language.Haskell.Exts as HSE_
 
 
 class View a b where
@@ -87,15 +86,6 @@ instance Named (QName S) where
     toNamed ":" = Special an $ Cons an
     toNamed x = UnQual an $ toNamed x
 
-instance Named HSE_.QName where
-    fromNamed (HSE_.Special HSE_.Cons) = ":"
-    fromNamed (HSE_.Special HSE_.UnitCon) = "()"
-    fromNamed (HSE_.UnQual x) = fromNamed x
-    fromNamed _ = ""
-
-    toNamed ":" = HSE_.Special HSE_.Cons
-    toNamed x = HSE_.UnQual $ toNamed x
-
 instance Named (Name S) where
     fromNamed (Ident _ x) = x
     fromNamed (Symbol _ x) = x
@@ -103,13 +93,6 @@ instance Named (Name S) where
     toNamed x | isSym x = Symbol an x
               | otherwise = Ident an x
 
-instance Named HSE_.Name where
-    fromNamed (HSE_.Ident x) = x
-    fromNamed (HSE_.Symbol x) = x
-
-    toNamed x | isSym x = HSE_.Symbol x
-              | otherwise = HSE_.Ident x
-
 instance Named (ModuleName S) where
     fromNamed (ModuleName _ x) = x
     toNamed = ModuleName an
@@ -153,7 +136,7 @@ instance Named (Decl S) where
     fromNamed (TypeDecl _ name _) = fromNamed name
     fromNamed (DataDecl _ _ _ name _ _) = fromNamed name
     fromNamed (GDataDecl _ _ _ name _ _ _) = fromNamed name
-    fromNamed (TypeFamDecl _ name _) = fromNamed name
+    fromNamed (TypeFamDecl _ name _ _) = fromNamed name
     fromNamed (DataFamDecl _ _ name _) = fromNamed name
     fromNamed (ClassDecl _ _ name _ _) = fromNamed name
     fromNamed (PatBind _ (PVar _ name) _ _) = fromNamed name
