@@ -5,7 +5,7 @@ module Hint.All(
     ) where
 
 import Data.Monoid
-import Settings
+import Config.Type
 import Data.Either
 import Data.List
 import Hint.Type
@@ -25,6 +25,7 @@ import Hint.Extensions
 import Hint.Duplicate
 import Hint.Comment
 import Hint.Unsafe
+import Hint.NewType
 
 -- | A list of the builtin hints wired into HLint.
 --   This list is likely to grow over time.
@@ -32,7 +33,7 @@ data HintBuiltin =
     HintList | HintListRec | HintMonad | HintLambda |
     HintBracket | HintNaming | HintPattern | HintImport |
     HintPragma | HintExtensions | HintUnsafe | HintDuplicate |
-    HintComment
+    HintComment | HintNewType
     deriving (Show,Eq,Ord,Bounded,Enum)
 
 
@@ -51,6 +52,7 @@ builtin x = case x of
     HintUnsafe     -> modu unsafeHint
     HintDuplicate  -> mods duplicateHint
     HintComment    -> comm commentHint
+    HintNewType    -> decl newtypeHint
     where
         decl x = mempty{hintDecl=x}
         modu x = mempty{hintModule=x}
@@ -62,10 +64,11 @@ builtin x = case x of
 builtinHints :: [(String, Hint)]
 builtinHints = [(drop 4 $ show h, resolveHints [Left h]) | h <- [minBound .. maxBound]]
 
--- | Transform a list of 'HintRule' into a 'Hint'.
+-- | Transform a list of 'HintBuiltin' or 'HintRule' into a 'Hint'.
 resolveHints :: [Either HintBuiltin HintRule] -> Hint
 resolveHints xs = mconcat $ mempty{hintDecl=readMatch rights} : map builtin (nub lefts)
     where (lefts,rights) = partitionEithers xs
 
+-- | Transform a list of 'HintRule' into a 'Hint'.
 hintRules :: [HintRule] -> Hint
 hintRules = resolveHints . map Right
