@@ -69,6 +69,20 @@ f :: x -> (x, x); f x = (x, x) --
 class Val a where; val :: a --
 {-# LANGUAGE DefaultSignatures #-} \
 class Val a where; val :: a; default val :: Int
+{-# LANGUAGE TypeApplications #-} \
+foo = id --
+{-# LANGUAGE TypeApplications #-} \
+foo = id @Int
+{-# LANGUAGE LambdaCase #-} \
+foo = id --
+{-# LANGUAGE LambdaCase #-} \
+foo = \case () -> ()
+{-# LANGUAGE NumDecimals #-} \
+foo = 12.3e2
+{-# LANGUAGE NumDecimals #-} \
+foo = id --
+{-# LANGUAGE NumDecimals #-} \
+foo = 12.345e2 --
 </TEST>
 -}
 
@@ -78,6 +92,7 @@ module Hint.Extensions(extensionsHint) where
 import Hint.Type
 import Data.Maybe
 import Data.List.Extra
+import Data.Ratio
 import Refact.Types
 
 
@@ -112,6 +127,7 @@ noNewtypeDeriving = ["Read","Show","Data","Typeable","Generic","Generic1"]
 
 usedExt :: Extension -> Module_ -> Bool
 usedExt (EnableExtension x) = used x
+usedExt (UnknownExtension "NumDecimals") = hasS isWholeFrac
 usedExt _ = const True
 
 
@@ -120,6 +136,7 @@ used RecursiveDo = hasS isMDo & hasS isRecStmt
 used ParallelListComp = hasS isParComp
 used FunctionalDependencies = hasT (un :: FunDep S)
 used ImplicitParams = hasT (un :: IPName S)
+used TypeApplications = hasS isTypeApp
 used EmptyDataDecls = hasS f
     where f (DataDecl _ _ _ _ [] _) = True
           f (GDataDecl _ _ _ _ _ [] _) = True
@@ -142,7 +159,7 @@ used RecordWildCards = hasS isPFieldWildcard & hasS isFieldWildcard
 used RecordPuns = hasS isPFieldPun & hasS isFieldPun
 used UnboxedTuples = has (not . isBoxed)
 used PackageImports = hasS (isJust . importPkg)
-used QuasiQuotes = hasS isQuasiQuote
+used QuasiQuotes = hasS isQuasiQuote & hasS isTyQuasiQuote
 used ViewPatterns = hasS isPViewPat
 used DefaultSignatures = hasS isClsDefSig
 used DeriveDataTypeable = hasDerive ["Data","Typeable"]
@@ -151,6 +168,7 @@ used DeriveFoldable = hasDerive ["Foldable"]
 used DeriveTraversable = hasDerive ["Traversable"]
 used DeriveGeneric = hasDerive ["Generic","Generic1"]
 used GeneralizedNewtypeDeriving = any (`notElem` noNewtypeDeriving) . fst . derives
+used LambdaCase = hasS isLCase
 used Arrows = hasS f
     where f Proc{} = True
           f LeftArrApp{} = True
@@ -213,3 +231,8 @@ hasS test = any test . universeBi
 
 has f = any f . universeBi
 
+-- Only whole number fractions are permitted by NumDecimals extension.
+-- Anything not-whole raises an error.
+isWholeFrac :: Literal S -> Bool
+isWholeFrac (Frac _ v _) = denominator v == 1
+isWholeFrac _ = False
