@@ -33,10 +33,6 @@ import qualified List -- import qualified Data.List as List
 import Char(foo) -- import Data.Char(foo)
 import IO(foo)
 import IO as X -- import System.IO as X; import System.IO.Error as X; import Control.Exception  as X (bracket,bracket_)
-module Foo(module A, baz, module B, module C) where; import A; import D; import B(map,filter); import C \
-    -- module Foo(baz, module X) where; import A as X; import B as X(map, filter); import C as X
-module Foo(module A, baz, module B, module X) where; import A; import B; import X \
-    -- module Foo(baz, module Y) where; import A as Y; import B as Y; import X as Y
 </TEST>
 -}
 
@@ -56,8 +52,7 @@ import Prelude
 importHint :: ModuHint
 importHint _ x = concatMap (wrap . snd) (groupSort
                  [((fromNamed $ importModule i,importPkg i),i) | i <- universeBi x, not $ importSrc i]) ++
-                 concatMap (\x -> hierarchy x ++ reduce1 x) (universeBi x) ++
-                 multiExport x
+                 concatMap (\x -> hierarchy x ++ combine1 x) (universeBi x)
 
 
 wrap :: [ImportDecl S] -> [Idea]
@@ -75,13 +70,13 @@ simplify (x:xs) = case simplifyHead x xs of
 
 simplifyHead :: ImportDecl S -> [ImportDecl S] -> Maybe ([ImportDecl S], [Refactoring R.SrcSpan])
 simplifyHead x [] = Nothing
-simplifyHead x (y:ys) = case reduce x y of
+simplifyHead x (y:ys) = case combine x y of
     Nothing -> first (y:) <$> simplifyHead x ys
     Just (xy, rs) -> Just (xy : ys, rs)
 
 
-reduce :: ImportDecl S -> ImportDecl S -> Maybe (ImportDecl S, [Refactoring R.SrcSpan])
-reduce x y | qual, as, specs = Just (x, [Delete Import (toSS y)])
+combine :: ImportDecl S -> ImportDecl S -> Maybe (ImportDecl S, [Refactoring R.SrcSpan])
+combine x y | qual, as, specs = Just (x, [Delete Import (toSS y)])
            | qual, as, Just (ImportSpecList _ False xs) <- importSpecs x, Just (ImportSpecList _ False ys) <- importSpecs y = let newImp = x{importSpecs = Just $ ImportSpecList an False $ nub_ $ xs ++ ys}
             in Just (newImp, [ Replace Import (toSS x)  [] (prettyPrint newImp)
                              , Delete Import (toSS y) ] )
@@ -99,14 +94,14 @@ reduce x y | qual, as, specs = Just (x, [Delete Import (toSS y)])
         ass = mapMaybe importAs [x,y]
         specs = importSpecs x `eqMaybe` importSpecs y
 
-reduce _ _ = Nothing
+combine _ _ = Nothing
 
 
-reduce1 :: ImportDecl S -> [Idea]
-reduce1 i@ImportDecl{..}
+combine1 :: ImportDecl S -> [Idea]
+combine1 i@ImportDecl{..}
     | Just (dropAnn importModule) == fmap dropAnn importAs
     = [suggest "Redundant as" i i{importAs=Nothing} [RemoveAsKeyword (toSS i)]]
-reduce1 _ = []
+combine1 _ = []
 
 
 newNames = let (*) = flip (,) in
@@ -149,24 +144,3 @@ hierarchy _ = []
 desugarQual :: ImportDecl S -> ImportDecl S
 desugarQual x | importQualified x && isNothing (importAs x) = x{importAs=Just (importModule x)}
               | otherwise = x
-
-
-multiExport :: Module S -> [Idea]
-multiExport x =
-    [ rawIdeaN Suggestion "Use import/export shortcut" (toSrcSpan $ ann hd)
-        (unlines $ prettyPrint hd : map prettyPrint imps)
-        (Just $ unlines $ prettyPrint newhd : map prettyPrint newimps)
-        []
-    | Module l (Just hd) _ imp _ <- [x]
-    , let asNames = mapMaybe importAs imp
-    , let expNames = [x | EModuleContents _ x <- childrenBi hd]
-    , let imps = [i | i@ImportDecl{importAs=Nothing,importQualified=False,importModule=name} <- imp
-                 ,name `notElem_` asNames, name `elem_` expNames]
-    , length imps >= 3
-    , let newname = ModuleName an $ head $ map return ("XYZ" ++ ['A'..]) \\
-                                           [x | ModuleName (_ :: S) x <- universeBi hd ++ universeBi imp]
-    , let reexport (EModuleContents _ x) = x `notElem_` map importModule imps
-          reexport x = True
-    , let newhd = descendBi (\xs -> filter reexport xs ++ [EModuleContents an newname]) hd
-    , let newimps = [i{importAs=Just newname} | i <- imps]
-    ]
