@@ -44,7 +44,7 @@ import Data.List.Extra
 import Data.Maybe
 import Data.Data
 import Unsafe.Coerce
-import Settings
+import Config.Type
 import Hint.Type
 import Control.Monad
 import Data.Tuple.Extra
@@ -165,7 +165,7 @@ nmOp nm  _ _ = False
 unify :: Data a => NameMatch -> Bool -> a -> a -> Maybe [(String,Exp_)]
 unify nm root x y | Just x <- cast x = unifyExp nm root x (unsafeCoerce y)
                   | Just x <- cast x = unifyPat nm x (unsafeCoerce y)
-                  | Just (x :: SrcSpanInfo) <- cast x = Just []
+                  | Just (x :: S) <- cast x = Just []
                   | otherwise = unifyDef nm x y
 
 
@@ -292,7 +292,7 @@ checkDefine _ _ _ = True
 
 -- if it has _eval_ do evaluation on it
 performEval :: Exp_ -> Exp_
-performEval (App _ e x) | e ~= "_eval_" = evaluate x
+performEval (App _ e x) | e ~= "_eval_" = reduce x
 performEval x = x
 
 
